/*
 *  Linux kernel adaptation layers for owl wifi library.
 *  Copyright (C) 2010 HD Wireless AB
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef OWL_NET_H
#define OWL_NET_H

#include <linux/skbuff.h>
#include <linux/netdevice.h>
#include <linux/etherdevice.h>
#include <linux/wireless.h>
#include <linux/timer.h>

#include "wl_api.h"

#define OWL_MAX_KEY_LEN 32

struct key_info {
        char key[OWL_MAX_KEY_LEN];
        unsigned char len;
};

struct owl_net {
        struct owl_transport *transport;
        struct net_device *dev;
        struct net_device_stats stats;
        wait_queue_head_t waitq;
        unsigned long flags;
#define INIT_COMPLETE           0
#define SCAN_COMPLETE           1

        struct semaphore wl_sema;
        struct timer_list wl_timer;
        struct work_struct wl_work;

        struct iw_statistics wireless_stats;

        enum wl_auth_mode auth_mode;
        
        struct key_info key_info[4];
        unsigned int default_key;
        int auth_param[13]; /* wireless.h */

        unsigned int ps_traffic_timeout;
        unsigned int ps_enabled;
};

struct owl_transport {
        void (*tx)(struct owl_transport *transport, struct sk_buff *skb);
        int (*fw_download)(struct owl_transport *transport, const char *fw,
                           int len);

        void (*wakeup)(struct owl_transport *transport, int wakeup);
    
        /* written by owl_net, should not be touched by owl_drv */
        struct owl_net *net;
};

void owl_net_rx(struct owl_transport *transport, struct sk_buff *skb);
int owl_net_register_drv(struct owl_transport *transport);
void owl_net_unregister_drv(struct owl_transport *transport);

#endif
