/*
 *  Linux kernel adaptation layers for owl wifi library.
 *  Copyright (C) 2010 HD Wireless AB
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <linux/module.h>
#include <linux/kernel.h>
#include <linux/string.h>
#include <linux/hardirq.h>
#include <stdarg.h>

/*
 * library functions needed by wl_api
 *
 */

void *owl_os_alloc(int size)
{
        return kmalloc(size, GFP_ATOMIC);
}

void owl_os_free(void *p)
{
        kfree(p);
}

void *owl_os_memcpy(void *dst, const void *src, size_t n)
{
        return memcpy(dst, src, n);
}

void *owl_os_memset(void *s, int c, size_t n)
{
        return memset(s, c, n);
}

size_t owl_os_strlen(char *s)
{
        return strlen(s);
}

char *owl_os_strncpy(char *dst, const char *src, size_t n)
{
        return strncpy(dst, src, n);
}

int owl_os_strncmp(const char *s1, const char *s2, size_t n)
{
        return strncmp(s1, s2, n);
}

char *owl_os_strcpy(char *dst, const char *src)
{
        return strcpy(dst, src);
}

int owl_os_memcmp(const void *s1, const void *s2, size_t n)
{
        return memcmp(s1, s2, n);
}

long int owl_os_strtol(const char *nptr, char **endptr, int base)
{
        return simple_strtol(nptr, endptr, base);
}

char *owl_os_strchr(const char *s, int c)
{
        return strchr(s, c);
}

int owl_os_snprintf(char *str, size_t size, const char *format, ...)
{
        return snprintf(str, size, format);
}

unsigned long int owl_os_strtoul(const char *nptr, char **endptr, int base)
{
        return simple_strtoul(nptr, endptr, base);
}
