/*
 *  Linux kernel adaptation layers for owl wifi library.
 *  Copyright (C) 2010 HD Wireless AB
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <net/iw_handler.h>
#include <linux/if_arp.h>

#include "owl_wext_event.h"


/*
 * driver_wext.c:wpa_driver_wext_event_wireless() expects to receive
 * SIOCGIWSCAN when an initiated scan has completed. According to
 * net/wireless/wext.c, SIOCGIWSCAN has an IW_HEADER_TYPE_POINT header_type, so
 * we better make sure that the wrqu.data is filled in properly.
 *
 */
void owl_wext_event_scan_complete(struct owl_net *priv) 
{
        struct net_device *dev = priv->dev;
        union iwreq_data wrqu;
        
        dev_dbg(&dev->dev, "ENTER %s\n", __func__);
        memset(&wrqu, 0, sizeof(wrqu));
        wireless_send_event(dev, SIOCGIWSCAN, &wrqu, NULL);
}

/*
 * Notify wpa_supplicant of connection state.
 *
 *
 */
void owl_wext_event_ap(struct owl_net *priv, struct wl_mac_addr_t *bssid)
{
        struct net_device *dev = priv->dev;
        union iwreq_data wrqu;
        
        dev_dbg(&dev->dev, "ENTER %s\n", __func__);

        memset(&wrqu, 0, sizeof(wrqu));
        wrqu.ap_addr.sa_family = ARPHRD_ETHER;
        if (bssid == NULL)
                memset(wrqu.ap_addr.sa_data, 0, ETH_ALEN);
        else
                memcpy(wrqu.ap_addr.sa_data, bssid->octet, ETH_ALEN);
        
        wireless_send_event(dev, SIOCGIWAP, &wrqu, NULL);
}


void owl_wext_event_micfailure(struct owl_net *priv)
{
        struct net_device *dev = priv->dev;
        union iwreq_data wrqu;
        struct iw_michaelmicfailure mic;
        
        dev_info(&dev->dev, "ENTER %s\n", __func__);

        memset(&wrqu, 0, sizeof(wrqu));
        wrqu.data.length = sizeof(mic);

        /* not used by wpa_supplicant */
        memset(&mic, 0, sizeof(mic));
        
        wireless_send_event(dev, IWEVMICHAELMICFAILURE, &wrqu, (void *) &mic);
}
